module.exports = {
	input: ['main1.js', 'main2.js'],
	output: {
		format: 'cjs'
	}
};
